==> AxolotlClient-3.1.6%2B1.20.1-sources.jar: io/github/axolotlclient/modules/hypixel/autoboop/FilterListConfigurationScreen.java <==
/*
 * Copyright © 2025 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.modules.hypixel.autoboop;

import java.util.List;
import net.minecraft.class_2561;
import net.minecraft.class_332;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_5244;
import io.github.axolotlclient.AxolotlClientCommon;

public class FilterListConfigurationScreen extends class_437 {
	final List<String> filters;
	private FiltersList filtersList;
	private final class_437 parent;

	public FilterListConfigurationScreen(List<String> filters, class_437 parent) {
		super(class_2561.method_43471("autoboop.filters.configure"));
		this.filters = filters;
		this.parent = parent;
	}

	@Override
	public void method_25394(class_332 graphics, int mouseX, int mouseY, float delta) {
		method_25420(graphics);
		super.method_25394(graphics, mouseX, mouseY, delta);
		graphics.method_27534(field_22793, method_25440(), field_22789 / 2, 33 / 2 - field_22793.field_2000 / 2, -1);
	}

	@Override
	protected void method_25426() {
		this.filtersList = method_37063(new FiltersList(this));
		class_4185 resetButton = class_4185.method_46430(class_2561.method_43471("autoboop.filters.clear"), button -> {
			filters.clear();
			filtersList.reload();
			AxolotlClientCommon.getInstance().saveConfig();
		}).method_46434(field_22789 / 2 - 150 - 4, field_22790 - 33 / 2 - 10, 150, 20).method_46431();
		method_37063(resetButton);
		method_37063(class_4185.method_46430(class_5244.field_24334, button -> this.method_25419())
			.method_46434(field_22789 / 2 + 4, field_22790 - 33 / 2 - 10, 150, 20).method_46431());
	}

	@Override
	public void method_25419() {
		this.field_22787.method_1507(this.parent);
		filtersList.apply();
		AxolotlClientCommon.getInstance().saveConfig();
	}
}

==> AxolotlClient-3.1.7%2B1.21.11-sources.jar: io/github/axolotlclient/modules/hypixel/autoboop/FilterListConfigurationScreen.java <==
/*
 * Copyright © 2025 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.modules.hypixel.autoboop;

import java.util.List;
import net.minecraft.class_2561;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_5244;
import net.minecraft.class_8132;
import net.minecraft.class_8667;
import io.github.axolotlclient.AxolotlClientCommon;

public class FilterListConfigurationScreen extends class_437 {
	final List<String> filters;
	public final class_8132 layout = new class_8132(this);
	private final FiltersList filtersList;
	private final class_437 parent;

	public FilterListConfigurationScreen(List<String> filters, class_437 parent) {
		super(class_2561.method_43471("autoboop.filters.configure"));
		this.filters = filters;
		this.parent = parent;
		this.filtersList = new FiltersList(this);
	}

	@Override
	protected void method_25426() {
		layout.method_57726(method_25440(), field_22793);
		layout.method_48999(filtersList);
		class_4185 resetButton = class_4185.method_46430(class_2561.method_43471("autoboop.filters.clear"), button -> {
			filters.clear();
			filtersList.reload();
			AxolotlClientCommon.getInstance().saveConfig();
		}).method_46431();
		class_8667 linearLayout = this.layout.method_48996(class_8667.method_52742().method_52735(8));
		linearLayout.method_52736(resetButton);
		linearLayout.method_52736(class_4185.method_46430(class_5244.field_24334, button -> this.method_25419()).method_46431());
		this.layout.method_48206(this::method_37063);
		this.method_48640();
	}

	@Override
	protected void method_48640() {
		this.layout.method_48222();
		this.filtersList.method_57712(this.field_22789, this.layout);
		filtersList.reload();
	}

	@Override
	public void method_25419() {
		this.field_22787.method_1507(this.parent);
		filtersList.apply();
		AxolotlClientCommon.getInstance().saveConfig();
	}
}
